# Noctis SDK for Python

[![Build Status](https://img.shields.io/travis/com/your_github_username/noctis-sdk-python.svg?style=flat-square)](https://travis-ci.com/your_github_username/noctis-sdk-python)
[![PyPI version](https://img.shields.io/pypi/v/noctis-sdk.svg?style=flat-square)](https://pypi.python.org/pypi/noctis-sdk)
[![License](https://img.shields.io/github/license/your_github_username/noctis-sdk-python.svg?style=flat-square)](LICENSE)

## Overview

This Python package is the official SDK for the **NoctisNet API** (version **0.0.3**). It provides programmatic access to Noctis's comprehensive domain and IP intelligence capabilities, including:

*   **Vulpra Detect:** Discover potentially malicious domains targeting your organization.
*   **Vulpra Investigate:** Deep dive into threats, map adversary infrastructure, and conduct investigations.
*   **Vulpra Enrich:** Get immediate context for indicators at scale.
*   **Octopus & viaGraphLink (vGL):** Access underlying data powering Noctis tools (equivalent to DNSDB and SIE concepts).
*   **Classic Lookups & Monitors:** Perform traditional Whois, DNS lookups, reverse lookups, and monitor changes.
*   **Account Management & Feeds:** Manage your account and access intelligence feeds.

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project based on the NoctisNet API OpenAPI specification.

**Default API Base Path:** `https://frog.noctisnet.com`

## Requirements

*   Python 3.9+
*   Dependencies:
    *   `urllib3 >= 2.1.0, < 3.0.0`
    *   `python-dateutil >= 2.8.2`
    *   `pydantic >= 2`
    *   `typing-extensions >= 4.7.1`

## Installation

This package is generated without standard Python packaging files (`setup.py`, `pyproject.toml`). To use it in your project:

1.  **Copy the SDK Directory:** Copy the entire `noctis_sdk` directory into your project's source tree.
2.  **Install Dependencies:** Manually install the required dependencies using pip:
    ```bash
    pip install "urllib3>=2.1.0,<3.0.0" python-dateutil pydantic typing-extensions
    ```

Alternatively, you can add these dependencies to your project's `requirements.txt` file.

## Getting Started

Here's a basic example of how to configure the client and make an API call to get account information:

```python
import noctis_sdk
from noctis_sdk.rest import ApiException
from pprint import pprint

# --- Configuration ---
# Define the base path if different from the default
# configuration = noctis_sdk.Configuration(
#     host="https://your_custom_noctis_host.com"
# )

# Configure Bearer authorization (JWT): bearerAuth (Primary method shown in SDK examples)
# Replace 'YOUR_BEARER_TOKEN' with your actual token
configuration = noctis_sdk.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# --- API Client ---
# Enter a context with an instance of the API client
with noctis_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class you want to use
    # Example: Using the Account Information API
    api_instance = noctis_sdk.NoctisAccountInformationApi(api_client)

    # --- API Call ---
    # Define optional parameters (use defaults or provide specific values)
    app_partner = 'YourAppName' # Optional: Identify your application
    app_name = 'YourModuleName' # Optional: Identify the specific module
    app_version = 1.0           # Optional: Version of your integration

    try:
        # Make the API call
        print("Fetching account information...")
        api_response = api_instance.get_account_information(
            app_partner=app_partner,
            app_name=app_name,
            app_version=app_version
        )
        print("Successfully retrieved account information:")
        pprint(api_response)

    except ApiException as e:
        print(f"Exception when calling NoctisAccountInformationApi->get_account_information: {e}\n")
    except Exception as e:
         print(f"An unexpected error occurred: {e}\n")


# --- Example 2: Domain Profile Lookup ---
with noctis_sdk.ApiClient(configuration) as api_client:
    api_instance = noctis_sdk.NoctisClassicLookupReversingApi(api_client)
    domain_to_query = "noctisnet.com"

    try:
        print(f"\nFetching domain profile for: {domain_to_query}...")
        api_response = api_instance.get_domain_profile(query=domain_to_query)
        print("Successfully retrieved domain profile:")
        pprint(api_response)
    except ApiException as e:
        print(f"Exception when calling NoctisClassicLookupReversingApi->get_domain_profile: {e}\n")
    except Exception as e:
         print(f"An unexpected error occurred: {e}\n")
```

## Authentication

The primary authentication method configured in the generated SDK examples relies on a **Bearer Token (JWT)**.

*   **Bearer Token:** Set the `access_token` attribute in the `noctis_sdk.Configuration` object:
    ```python
    configuration = noctis_sdk.Configuration(
        access_token = 'YOUR_BEARER_TOKEN'
    )
    ```

The underlying NoctisNet API *may* also support other authentication methods like API keys (passed via query parameters or headers), as defined in the original OpenAPI specification. While the `Configuration` object has attributes (`api_key`, `username`, `password`), the generated `auth_settings()` method primarily utilizes the `access_token`. To use other methods consistently, you might need to customize the `ApiClient` or pass specific `_request_auth` dictionaries to API calls if the generator included support for multiple schemes per operation. Please refer to the official NoctisNet API documentation for details on all supported authentication schemes.

## Documentation

### API Endpoints

Detailed documentation for each API endpoint, including parameters and return types, can be found in the `docs` directory:

*   [AsnsApi](noctis_sdk/docs/AsnsApi.md)
*   [DNSResolutionApi](noctis_sdk/docs/DNSResolutionApi.md)
*   [DomainsApi](noctis_sdk/docs/DomainsApi.md)
*   [FileOperationsApi](noctis_sdk/docs/FileOperationsApi.md)
*   [NoctisAccountInformationApi](noctis_sdk/docs/NoctisAccountInformationApi.md)
*   [NoctisClassicLookupReversingApi](noctis_sdk/docs/NoctisClassicLookupReversingApi.md)
*   [NoctisClassicLookupReversingLegacyApi](noctis_sdk/docs/NoctisClassicLookupReversingLegacyApi.md)
*   [NoctisClassicMonitorsApi](noctis_sdk/docs/NoctisClassicMonitorsApi.md)
*   [NoctisFeedsApi](noctis_sdk/docs/NoctisFeedsApi.md)
*   [NoctisVulpraDetectApi](noctis_sdk/docs/NoctisVulpraDetectApi.md)
*   [NoctisVulpraEnrichApi](noctis_sdk/docs/NoctisVulpraEnrichApi.md)
*   [NoctisVulpraInvestigateApi](noctis_sdk/docs/NoctisVulpraInvestigateApi.md)
*   [ScoringAlgorithmSrApi](noctis_sdk/docs/ScoringAlgorithmSrApi.md)
*   [VisualizeApi](noctis_sdk/docs/VisualizeApi.md)

### Models

Documentation for the data models used in requests and responses:

*   [AccountData](noctis_sdk/docs/AccountData.md)
*   [AccountInfo](noctis_sdk/docs/AccountInfo.md)
*   [AccountInformationResponse](noctis_sdk/docs/AccountInformationResponse.md)
*   [BrandAlert](noctis_sdk/docs/BrandAlert.md)
*   [BrandMonitorData](noctis_sdk/docs/BrandMonitorData.md)
*   [BrandMonitorResponse](noctis_sdk/docs/BrandMonitorResponse.md)
*   [ContactDTO](noctis_sdk/docs/ContactDTO.md)
*   [ContactEnrichDTO](noctis_sdk/docs/ContactEnrichDTO.md)
*   [ContactKeys](noctis_sdk/docs/ContactKeys.md)
*   [DomainParsedWhois](noctis_sdk/docs/DomainParsedWhois.md)
*   [DomainProfileData](noctis_sdk/docs/DomainProfileData.md)
*   [DomainProfileResponse](noctis_sdk/docs/DomainProfileResponse.md)
*   [DomainReputationData](noctis_sdk/docs/DomainReputationData.md)
*   [DomainReputationResponse](noctis_sdk/docs/DomainReputationResponse.md)
*   [DomainRiskDTO](noctis_sdk/docs/DomainRiskDTO.md)
*   [DomainRiskScoreData](noctis_sdk/docs/DomainRiskScoreData.md)
*   [DomainRiskScoreEvidenceData](noctis_sdk/docs/DomainRiskScoreEvidenceData.md)
*   [DomainRiskScoreEvidenceResponse](noctis_sdk/docs/DomainRiskScoreEvidenceResponse.md)
*   [DomainRiskScoreResponse](noctis_sdk/docs/DomainRiskScoreResponse.md)
*   [DomainWhoisData](noctis_sdk/docs/DomainWhoisData.md)
*   [EntityTypes](noctis_sdk/docs/EntityTypes.md)
*   [EscalationInfoDTO](noctis_sdk/docs/EscalationInfoDTO.md)
*   [EscalationUpdateResultDTO](noctis_sdk/docs/EscalationUpdateResultDTO.md)
*   [FeedFileDTO](noctis_sdk/docs/FeedFileDTO.md)
*   [FeedListData](noctis_sdk/docs/FeedListData.md)
*   [FeedListResponse](noctis_sdk/docs/FeedListResponse.md)
*   [GenericValueDTOInteger](noctis_sdk/docs/GenericValueDTOInteger.md)
*   [GenericValueDTOLong](noctis_sdk/docs/GenericValueDTOLong.md)
*   [GenericValueDTOString](noctis_sdk/docs/GenericValueDTOString.md)
*   [GenericValueEnrichDTO](noctis_sdk/docs/GenericValueEnrichDTO.md)
*   [HistoryDetail](noctis_sdk/docs/HistoryDetail.md)
*   [HistorySummary](noctis_sdk/docs/HistorySummary.md)
*   [InvestigateResponseData](noctis_sdk/docs/InvestigateResponseData.md)
*   [IpAlert](noctis_sdk/docs/IpAlert.md)
*   [IpBasicDTO](noctis_sdk/docs/IpBasicDTO.md)
*   [IpContact](noctis_sdk/docs/IpContact.md)
*   [IpInfoEnrichDTO](noctis_sdk/docs/IpInfoEnrichDTO.md)
*   [IpInfoWithAsnDTO](noctis_sdk/docs/IpInfoWithAsnDTO.md)
*   [IpMonitorData](noctis_sdk/docs/IpMonitorData.md)
*   [IpMonitorResponse](noctis_sdk/docs/IpMonitorResponse.md)
*   [IpNetwork](noctis_sdk/docs/IpNetwork.md)
*   [IpParsedWhois](noctis_sdk/docs/IpParsedWhois.md)
*   [IpRange](noctis_sdk/docs/IpRange.md)
*   [IpRangeChange](noctis_sdk/docs/IpRangeChange.md)
*   [IpRegistrantMonitorData](noctis_sdk/docs/IpRegistrantMonitorData.md)
*   [IpRegistrantMonitorResponse](noctis_sdk/docs/IpRegistrantMonitorResponse.md)
*   [IpWhoisData](noctis_sdk/docs/IpWhoisData.md)
*   [MonitorDomainCountsDTO](noctis_sdk/docs/MonitorDomainCountsDTO.md)
*   [MxInfoDTO](noctis_sdk/docs/MxInfoDTO.md)
*   [MxInfoEnrichDTO](noctis_sdk/docs/MxInfoEnrichDTO.md)
*   [NameServerAlert](noctis_sdk/docs/NameServerAlert.md)
*   [NameServerBasicDTO](noctis_sdk/docs/NameServerBasicDTO.md)
*   [NameServerHistoryDetail](noctis_sdk/docs/NameServerHistoryDetail.md)
*   [NameServerInfo](noctis_sdk/docs/NameServerInfo.md)
*   [NameServerInfoDTO](noctis_sdk/docs/NameServerInfoDTO.md)
*   [NameServerInfoEnrichDTO](noctis_sdk/docs/NameServerInfoEnrichDTO.md)
*   [NameServerMonitorData](noctis_sdk/docs/NameServerMonitorData.md)
*   [NameServerMonitorResponse](noctis_sdk/docs/NameServerMonitorResponse.md)
*   [ParsedDomainWhoisDetails](noctis_sdk/docs/ParsedDomainWhoisDetails.md)
*   [ParsedIpWhoisDetails](noctis_sdk/docs/ParsedIpWhoisDetails.md)
*   [ProductInfo](noctis_sdk/docs/ProductInfo.md)
*   [RegistrantAlert](noctis_sdk/docs/RegistrantAlert.md)
*   [RegistrantInfo](noctis_sdk/docs/RegistrantInfo.md)
*   [RegistrantMonitorData](noctis_sdk/docs/RegistrantMonitorData.md)
*   [RegistrantMonitorResponse](noctis_sdk/docs/RegistrantMonitorResponse.md)
*   [RegistrarInfo](noctis_sdk/docs/RegistrarInfo.md)
*   [RegistrationInfo](noctis_sdk/docs/RegistrationInfo.md)
*   [RelationshipType](noctis_sdk/docs/RelationshipType.md)
*   [Response](noctis_sdk/docs/Response.md)
*   [RiskComponentEvidence](noctis_sdk/docs/RiskComponentEvidence.md)
*   [RiskComponentScore](noctis_sdk/docs/RiskComponentScore.md)
*   [RiskScoreComponentsDTO](noctis_sdk/docs/RiskScoreComponentsDTO.md)
*   [SeoInfo](noctis_sdk/docs/SeoInfo.md)
*   [ServerInfo](noctis_sdk/docs/ServerInfo.md)
*   [SslInfoDTO](noctis_sdk/docs/SslInfoDTO.md)
*   [SslInfoEnrichDTO](noctis_sdk/docs/SslInfoEnrichDTO.md)
*   [SslSourceInfo](noctis_sdk/docs/SslSourceInfo.md)
*   [TagInfoDTO](noctis_sdk/docs/TagInfoDTO.md)
*   [ThreatProfileScoresDTO](noctis_sdk/docs/ThreatProfileScoresDTO.md)
*   [TrackerInfoDTO](noctis_sdk/docs/TrackerInfoDTO.md)
*   [TripleHashMapStringEntityTypesRelationshipTypeHashMapStringEntityTypes](noctis_sdk/docs/TripleHashMapStringEntityTypesRelationshipTypeHashMapStringEntityTypes.md)
*   [UsageStats](noctis_sdk/docs/UsageStats.md)
*   [VulpraDetectDomainDTO](noctis_sdk/docs/VulpraDetectDomainDTO.md)
*   [VulpraDetectDomainListResponse](noctis_sdk/docs/VulpraDetectDomainListResponse.md)
*   [VulpraDetectDomainsUpdateRequest](noctis_sdk/docs/VulpraDetectDomainsUpdateRequest.md)
*   [VulpraDetectEscalationUpdateResponse](noctis_sdk/docs/VulpraDetectEscalationUpdateResponse.md)
*   [VulpraDetectEscalationsRequest](noctis_sdk/docs/VulpraDetectEscalationsRequest.md)
*   [VulpraDetectMonitorListResponse](noctis_sdk/docs/VulpraDetectMonitorListResponse.md)
*   [VulpraDetectWatchlistUpdateResponse](noctis_sdk/docs/VulpraDetectWatchlistUpdateResponse.md)
*   [VulpraEnrichData](noctis_sdk/docs/VulpraEnrichData.md)
*   [VulpraEnrichResponse](noctis_sdk/docs/VulpraEnrichResponse.md)
*   [VulpraEnrichResultDTO](noctis_sdk/docs/VulpraEnrichResultDTO.md)
*   [VulpraInvestigateResponse](noctis_sdk/docs/VulpraInvestigateResponse.md)
*   [VulpraInvestigateResultDTO](noctis_sdk/docs/VulpraInvestigateResultDTO.md)
*   [VulpraMonitorDTO](noctis_sdk/docs/VulpraMonitorDTO.md)
*   [WatchlistUpdateResultDTO](noctis_sdk/docs/WatchlistUpdateResultDTO.md)
*   [WebsiteData](noctis_sdk/docs/WebsiteData.md)
*   [WhoisContacts](noctis_sdk/docs/WhoisContacts.md)
*   [WhoisHistoryData](noctis_sdk/docs/WhoisHistoryData.md)
*   [WhoisHistoryDetail](noctis_sdk/docs/WhoisHistoryDetail.md)
*   [WhoisHistoryEntry](noctis_sdk/docs/WhoisHistoryEntry.md)
*   [WhoisHistoryResponse](noctis_sdk/docs/WhoisHistoryResponse.md)
*   [WhoisLookupData](noctis_sdk/docs/WhoisLookupData.md)
*   [WhoisLookupResponse](noctis_sdk/docs/WhoisLookupResponse.md)
*   [WhoisRecord](noctis_sdk/docs/WhoisRecord.md)

## Author

support@noctisnet.com
